
<br />
<p align="center">
    <a href="https://astroqtpy.readthedocs.io/en/latest/">
      <img src="docs/img/astroQTpy_logo_withtext.png" width="50%"/>
    </a>
</p>

<h1 align="center">Efficient 2D mapping for astronomers</h1>

<p align="center">
    <a href='https://astroqtpy.readthedocs.io/en/latest/?badge=latest' >
        <img src='https://readthedocs.org/projects/astroqtpy/badge/?version=latest' alt='Documentation Status' />
    </a>
    <a href="https://pypi.org/project/astroQTpy/">
        <img alt="PyPi" src="https://img.shields.io/pypi/v/astroQTpy">
    </a>
    <a href="https://zenodo.org/badge/latestdoi/666798611">
        <img src="https://zenodo.org/badge/666798611.svg" alt="DOI">
    </a>
    <a href="https://github.com/CalebHarada/astroQTpy/blob/main/LICENSE">
        <img src="https://img.shields.io/badge/license-MIT-yellow" alt="License">
    </a>
    <a href="https://github.com/CalebHarada/astroQTpy/tree/main">
        <img alt="GitHub" src="https://img.shields.io/badge/github-main-purple">
    </a>
</p>

Welcome to `astroQTpy` (Astronomy Quad Trees in Python), a Python package for efficiently mapping 2D parameter space using quadtrees. For installation instructions, tutorials, and detailed documentation: [read the docs](https://astroqtpy.readthedocs.io/en/latest/)!